<?php

namespace Marketup\PriceHistoryForWoocommerce;

class Settings {
    public int $keep_history_in_days = 30;

    public array $history_graph_hooks = [];

    public array $lowest_price_message_hooks = [];

    public function __construct() {
        $saved_option = get_option('marketup_price_history');

        if (! is_array($saved_option)) {
            return;
        }

        foreach ($saved_option as $key => $value) {
            if (property_exists($this, $key)) {
                $this->{$key} = $value;
            }
        }
    }

    public function get_keep_history_in_days() {
        switch ((int) $this->keep_history_in_days) {
            case 30:
            case 60:
            case 90:
                return $this->keep_history_in_days;
            default:
                return 30;
        }
    }

    public function register_settings() {
        register_setting('marketup_price_history', 'marketup_price_history');

        add_settings_section(
            'marketup_price_history',
            __('Price History Settings', 'marketup-price-history'),
            '__return_false',
            'marketup_price_history'
        );

        add_settings_field(
            'history_in_days',
            __('Keep History for', 'marketup-price-history'),
            function () {
                ?>
                <select name="marketup_price_history[keep_history_in_days]">
                    <option value="30" <?php selected(30, $this->keep_history_in_days) ?>>
                        <?php esc_html_e('30 days', 'marketup-price-history') ?>
                    </option>
                    <option value="60" <?php selected(60, $this->keep_history_in_days) ?>>
                        <?php esc_html_e('60 days', 'marketup-price-history') ?>
                    </option>
                    <option value="90" <?php selected(90, $this->keep_history_in_days) ?>>
                        <?php esc_html_e('90 days', 'marketup-price-history') ?>
                    </option>
                </select>
                <?php
            },
            'marketup_price_history',
            'marketup_price_history'
        );

        add_settings_field(
            'lowest_price_message_hooks',
            __('Show lowest price message at', 'marketup-price-history'),
            function () {
                ?>
                <fieldset>
                <label>
                    <input
                        type="checkbox"
                        name="marketup_price_history[lowest_price_message_hooks][]"
                        value="woocommerce_single_product_summary"
                        <?php checked(in_array('woocommerce_single_product_summary', $this->lowest_price_message_hooks)) ?>
                    >
                    <?php esc_html_e('Single product summary', 'marketup-price-history') ?>
                </label>
                </fieldset>
                <fieldset>
                <label>
                    <input
                        type="checkbox"
                        name="marketup_price_history[lowest_price_message_hooks][]"
                        value="woocommerce_after_shop_loop_item_title"
                        <?php checked(in_array('woocommerce_after_shop_loop_item_title', $this->lowest_price_message_hooks)) ?>
                    >
                    <?php esc_html_e('Shop page, after product title', 'marketup-price-history') ?>
                </label>
                </fieldset>
                <fieldset>
                <label>
                    <input
                        type="checkbox"
                        name="marketup_price_history[lowest_price_message_hooks][]"
                        value="woocommerce_after_shop_loop_item"
                        <?php checked(in_array('woocommerce_after_shop_loop_item', $this->lowest_price_message_hooks)) ?>
                    >
                    <?php esc_html_e('Shop page, after product item', 'marketup-price-history') ?>
                </label>
                </fieldset>
                <fieldset>
                <label>
                    <input
                        type="checkbox"
                        name="marketup_price_history[lowest_price_message_hooks][]"
                        value="woocommerce_before_shop_loop_item_title"
                        <?php checked(in_array('woocommerce_before_shop_loop_item_title', $this->lowest_price_message_hooks)) ?>
                    >
                    <?php esc_html_e('Shop page, before product title', 'marketup-price-history') ?>
                </label>
                </fieldset>
                <fieldset>
                <label>
                    <input
                        type="checkbox"
                        name="marketup_price_history[lowest_price_message_hooks][]"
                        value="woocommerce_before_shop_loop_item"
                        <?php checked(in_array('woocommerce_before_shop_loop_item', $this->lowest_price_message_hooks)) ?>
                    >
                    <?php esc_html_e('Shop page, before product item', 'marketup-price-history') ?>
                </label>
                </fieldset>
                <?php
                echo '<p>';
                echo wp_kses_post(
                    __('You may also use the <code>[marketup_lowest_price_history]</code> shortcode to display the message elsewhere.', 'marketup-price-history')
                );
                echo '</p>';
            },
            'marketup_price_history',
            'marketup_price_history'
        );

        add_settings_field(
            'history_graph_hooks',
            __('Show price history graph', 'marketup-price-history'),
            function () {
                ?>
                <fieldset>
                <label>
                    <input
                        type="checkbox"
                        name="marketup_price_history[history_graph_hooks][]"
                        value="woocommerce_single_product_summary"
                        <?php checked(in_array('woocommerce_single_product_summary', $this->history_graph_hooks)) ?>
                    >
                    <?php esc_html_e('Single product summary', 'marketup-price-history') ?>
                </label>
                </fieldset>
                <fieldset>
                <label>
                    <input
                        type="checkbox"
                        name="marketup_price_history[history_graph_hooks][]"
                        value="woocommerce_after_single_product_summary"
                        <?php checked(in_array('woocommerce_after_single_product_summary', $this->history_graph_hooks)) ?>
                    >
                    <?php esc_html_e('After single product summary', 'marketup-price-history') ?>
                </label>
                </fieldset>
                <?php
                echo '<p>';
                echo wp_kses_post(
                    __('You may also use the <code>[marketup_price_history_graph]</code> shortcode to display the message elsewhere.', 'marketup-price-history')
                );
                echo '</p>';
            },
            'marketup_price_history',
            'marketup_price_history'
        );
    }

    public function add_admin_menu() {
        add_options_page(
            __('Price History for WooCommerce', 'marketup-price-history'),
            __('Price History for WooCommerce', 'marketup-price-history'),
            'manage_options',
            'marketup_price_history',
            [$this, 'render_settings_page']
        );
    }

    public function render_settings_page() {
        if (! current_user_can('manage_options')) {
            return;
        }

        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <form method="post" action="options.php">
                <?php settings_fields('marketup_price_history'); ?>
                <?php do_settings_sections('marketup_price_history'); ?>
                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }
}
